@@ -170,7 +170,7 @@ sub setup {
     debug(2, "writing $filename");
     unless ($args{dry_run}) {
 	my $challenge_dir = "$www_root/.well-known/acme-challenge";
-	my $acme_dir = "/etc/ssl/acme";
+	my $acme_dir = $App::Acmeman::acme_dir;
 
 	foreach my $dir ($self->layout->incdir(), $challenge_dir, $acme_dir) {
 	    unless ($self->mkpath($dir)) {
@@ -207,7 +207,7 @@ sub setup {
     SSLCipherSuite ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:AES:CAMELLIA:!DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA
     SSLCertificateFile $acme_dir/\$domain/cert.pem
     SSLCertificateKeyFile $acme_dir/\$domain/privkey.pem
-    SSLCACertificateFile $acme_dir/lets-encrypt-x3-cross-signed.pem
+    SSLCACertificateFile $acme_dir/$App::Acmeman::letsencrypt_root_cert_basename
 </Macro>
 
 <Macro LetsEncryptServer \$domain>
